@@ -57,14 +57,13 @@ Dataset::sortChunks() {
 }
 
 Dataset::MetricsPtr
-Dataset::getMetric(std::string   metricName)
+Dataset::getMetric(std::string   metricName, long start, long end)
 {
     auto v = hashMapMetrics[metricName];
-
     if (!v) {
         uint64_t *data;
         if (chunkVector.size() > 0) {
-            data = new uint64_t [samplesInDataset];
+            data = new uint64_t[samplesInDataset];
 
             // fill them now
             uint64_t *p = data;
@@ -72,16 +71,17 @@ Dataset::getMetric(std::string   metricName)
                 m->getMetric(metricName, p);
                 p += m->getSamplesCount();
             }
-            v = new Dataset::Metrics ();
-            v->insert(v->begin(), data, data+samplesInDataset);
-            addMergedMetric( metricName, v);
-            delete [] data;
+            v = new Dataset::Metrics();
+            v->insert(v->begin(), data, data + samplesInDataset);
+            addMergedMetric(metricName, v);
+            delete[] data;
         }
     }
     return v;
 }
 
 
+
 void Dataset::FileParsed() {
 
     int metricsNameLen = 0;
