@@ -10,7 +10,7 @@
 #include <boost/log/trivial.hpp>
 #include <boost/log/expressions.hpp>
 // From libbson
-#include <bson.h>
+#include <bson/bson.h>
 #include <boost/thread.hpp>
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/classification.hpp>
@@ -244,7 +244,7 @@ FTDCParser::getMetricsNames() {
     return metricNames;
 }
 
-Dataset::Metrics *
-FTDCParser::getMetric(std::string name) {
-     return dataSet.getMetric(name);
+Dataset::MetricsPtr
+FTDCParser::getMetric(std::string name, long start, long end) {
+     return dataSet.getMetric(name, start, end);
 }
