@@ -14,7 +14,7 @@
 #include <string>
 
 // From libbson
-#include <bson.h>
+#include <bson/bson.h>
 
 #include <boost/program_options.hpp>
 
@@ -31,7 +31,7 @@ public:
     std::vector<std::string> getMetricsNamesPrefixed(std::string prefix) ;
     std::vector<std::string> getMetricsNames();
 
-    Dataset::MetricsPtr getMetric(std::string   name) ;
+    Dataset::MetricsPtr getMetric(std::string name, long start=-1, long end=-1);
  
     size_t getMetricLength() { return dataSet.getMetricLength(); }
     std::vector<Chunk*> getChunks() { return dataSet.getChunkVector(); }
